/**
 * A simple test case that determines if elements, specified by a selector,
 * exist or not.
 *
 * The test fails for elements that are found and a case is created for each
 * one. The test passes is the selector finds no matching elements.
 */
var Case = require('Case');
const DOM = require('DOM');

var TableIsGrouped = {
  run: function (test, options) {

    var selector = 'table';

    test.get('scope').forEach(function (scope) {
      var candidates = DOM.scry(selector, scope)
        .filter((element) => {
          let theads = DOM.scry('thead', element);
          let tfoots = DOM.scry('tfoot', element);
          return theads.length === 0 || tfoots.length === 0;
        });
      if (!candidates.length) {
        test.add(Case({
          element: undefined,
          status: (options.test ? 'inapplicable' : 'passed')
        }));
      }
      else {
        candidates.forEach(function (element) {
          var status;

          // If a test is defined, then use it
          if (options.test && !DOM.is(element, options.test)) {
            status = 'passed';
          }
          else {
            status = 'failed';
          }

          test.add(Case({
            element: element,
            status: status
          }));
        });
      }
    });
  },

  meta: {
    testability: 0.5,
    title: {
      en: 'Mark up the areas of tables using thead and tbody',
      nl: 'Gebruik thead en tbody voor tabellen'
    },
    description: {
      en: 'Mark up the areas of tables using thead and tbody.',
      nl: 'Gebruik thead en tbody voor tabellen.'
    },
    guidelines: [

    ],
    tags: [
      'table',
      'content'
    ]
  }
};
module.exports = TableIsGrouped;
